summaryrefslogtreecommitdiff
path: root/libs/midi++2
diff options
context:
space:
mode:
authorRobin Gareus <robin@gareus.org>2019-04-08 03:46:02 +0200
committerRobin Gareus <robin@gareus.org>2019-04-08 04:10:04 +0200
commit46f0b75e124e5c017e0fe1790769c2d2f28e7918 (patch)
tree313fa2293a605f45e0fda25581e5ab3a87218a6a /libs/midi++2
parent889bd35f4fa390d33dc3f280a919495e6483611e (diff)
Undo more incorrect sample/frame replacements
Diffstat (limited to 'libs/midi++2')
-rw-r--r--libs/midi++2/mtc.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/libs/midi++2/mtc.cc b/libs/midi++2/mtc.cc
index f6ad97d4e2..dbe63f7c26 100644
--- a/libs/midi++2/mtc.cc
+++ b/libs/midi++2/mtc.cc
@@ -189,7 +189,7 @@ Parser::process_mtc_quarter_frame (MIDI::byte *msg)
if (res.get_value_or (false)) {
/* no error, reset next expected sample */
switch (_mtc_running) {
case MTC_Forward:
@@ -222,7 +222,7 @@ Parser::process_mtc_quarter_frame (MIDI::byte *msg)
/* skip counts as an error ... go back to waiting for the first sample */
#ifdef DEBUG_MTC
- cerr << "Skipped MTC qtr sample, return to stopped state" << endl;
+ cerr << "Skipped MTC qtr frame, return to stopped state" << endl;
#endif
reset_mtc_state ();
mtc_status (MTC_Stopped);
@@ -231,7 +231,7 @@ Parser::process_mtc_quarter_frame (MIDI::byte *msg)
} else {
/* received qtr sample matched expected */
consecutive_qtr_frame_cnt++;
}
@@ -189,7 +189,7 @@ Parser::process_mtc_quarter_frame (MIDI::byte *msg)
if (res.get_value_or (false)) {
- /* no error, reset next expected sample */
+ /* no error, reset next expected frame */
switch (_mtc_running) {
case MTC_Forward:
@@ -231,7 +231,7 @@ Parser::process_mtc_quarter_frame (MIDI::byte *msg)
} else {
- /* received qtr sample matched expected */
+ /* received qtr frame matched expected */
consecutive_qtr_frame_cnt++;
}